@@ -15,7 +15,7 @@ require_relative "firefox"
 require_relative "edge"
 require_relative "opera"
 require_relative "blackberry"
-require_relative "generic"
+require_relative "unknown"
 require_relative "phantom_js"
 require_relative "uc_browser"
 require_relative "nokia"
@@ -32,6 +32,11 @@ require_relative "sputnik"
 require_relative "snapchat"
 require_relative "duck_duck_go"
 require_relative "samsung_browser"
+require_relative "huawei_browser"
+require_relative "miui_browser"
+require_relative "maxthon"
+require_relative "sougou_browser"
+require_relative "google_search_app"
 
 require_relative "bot"
 require_relative "bot/empty_user_agent_matcher"
@@ -46,10 +51,19 @@ require_relative "meta"
 module Browser
   EMPTY_STRING = ""
 
+  Error = Class.new(StandardError)
+
   def self.root
     @root ||= Pathname.new(File.expand_path("../..", __dir__))
   end
 
+  class << self
+    attr_accessor :user_agent_size_limit, :accept_language_size_limit
+  end
+
+  self.user_agent_size_limit = 2048
+  self.accept_language_size_limit = 2048
+
   # Hold the list of browser matchers.
   # Order is important.
   def self.matchers
@@ -75,9 +89,14 @@ module Browser
       Sputnik,              # must be placed before Chrome and Safari
       DuckDuckGo,           # must be placed before Chrome and Safari
       SamsungBrowser,       # must be placed before Chrome and Safari
+      HuaweiBrowser,        # must be placed before Chrome and Safari
+      MiuiBrowser,          # must be placed before Chrome and Safari
+      Maxthon,              # must be placed before Chrome and Safari
+      SougouBrowser,        # must be placed before Chrome and Safari
+      GoogleSearchApp,      # must be placed before Chrome and Safari
       Chrome,
       Safari,
-      Generic
+      Unknown
     ]
   end
 
