@@ -20,14 +20,20 @@ module Browser
     end
 
     def match?
-      ua =~ /Chrome|CriOS/ &&
-        ua !~ /PhantomJS|FxiOS|ArchiveBot/ &&
+      ua.match?(/Chrome|CriOS/) &&
+        !ua.match?(/PhantomJS|FxiOS|ArchiveBot/) &&
         !opera? &&
         !edge? &&
         !duck_duck_go? &&
         !yandex? &&
         !sputnik? &&
-        !samsung_browser?
+        !samsung_browser? &&
+        !huawei_browser? &&
+        !miui_browser? &&
+        !maxthon? &&
+        !qq? &&
+        !sougou_browser? &&
+        !google_search_app?
     end
   end
 end
