@@ -5,7 +5,7 @@ module Browser
     class IOS < Base
       MATCHER = /(iPhone|iPad|iPod)/.freeze
       VERSION_MATCHER =
-        /OS ((?<major>\d+)_(?<minor>\d+)_?(?<patch>\d+)?)/.freeze
+        /OS (?<major>\d+)_(?<minor>\d+)_?(?<patch>\d+)?/.freeze
 
       def version
         matches = VERSION_MATCHER.match(ua)
@@ -32,7 +32,7 @@ module Browser
       end
 
       def match?
-        ua =~ MATCHER
+        ua.match?(MATCHER)
       end
 
       def device
