@@ -18,14 +18,22 @@ module Browser
     end
 
     def match?
-      ua =~ /Safari/ &&
-        ua !~ /PhantomJS|FxiOS/ &&
+      ua.include?("Safari") &&
+        !ua.match?(/PhantomJS|FxiOS/) &&
         !edge? &&
         !chrome? &&
+        !opera? &&
         !samsung_browser? &&
+        !huawei_browser? &&
+        !miui_browser? &&
         !duck_duck_go? &&
         !yandex? &&
-        !sputnik?
+        !sputnik? &&
+        !maxthon? &&
+        !qq? &&
+        !alipay? &&
+        !sougou_browser? &&
+        !google_search_app?
     end
   end
 end
