@@ -106,14 +106,13 @@ class BrowserTest < Minitest::Test
     refute browser.chrome?(">=65")
   end
 
-  test "detects unknown id" do
+  test "detects unknown browser" do
     browser = Browser.new("Unknown")
-    assert_equal :generic, browser.id
-  end
 
-  test "detects unknown name" do
-    browser = Browser.new("Unknown")
-    assert_equal "Generic Browser", browser.name
+    assert browser.unknown?
+    refute browser.known?
+    assert_equal :unknown_browser, browser.id
+    assert_equal "Unknown Browser", browser.name
   end
 
   test "returns empty language set for missing accept language" do
@@ -155,4 +154,36 @@ class BrowserTest < Minitest::Test
     browser = Browser.new("Fancy new browser")
     refute browser.known?
   end
+
+  test "rejects user agent larger than 2048 bytes" do
+    message = "user_agent cannot be larger than 2048 bytes; actual size is " \
+              "2049 bytes"
+
+    error =
+      begin
+        Browser.new("a" * 2049)
+        nil
+      rescue Browser::Error => error
+        error
+      end
+
+    refute_nil error
+    assert_equal message, error.message
+  end
+
+  test "rejects accept language larger than 2048 bytes" do
+    message = "accept_language cannot be larger than 2048 bytes; actual size " \
+              "is 2049 bytes"
+
+    error =
+      begin
+        Browser.new("Chrome", accept_language: "a" * 2049).accept_language
+        nil
+      rescue Browser::Error => error
+        error
+      end
+
+    refute_nil error
+    assert_equal message, error.message
+  end
 end
