@@ -3,7 +3,7 @@
 require "simplecov"
 SimpleCov.start
 
-ENV["BUNDLE_GEMFILE"] ||= File.expand_path("../../Gemfile", __FILE__)
+ENV["BUNDLE_GEMFILE"] ||= File.expand_path("../Gemfile", __dir__)
 require "bundler/setup"
 require "minitest/autorun"
 require "minitest/utils"
@@ -24,3 +24,11 @@ module Minitest
     end
   end
 end
+
+# Override Browser::Base#warn, so we don't output deprecation messages.
+module Browser
+  class Base
+    def warn(*)
+    end
+  end
+end
